@@ -50,7 +50,7 @@ struct _CamelExchangeStoreClass {
 
 GType		camel_exchange_store_get_type	(void);
 gboolean	camel_exchange_store_connected	(CamelExchangeStore *store,
-						 CamelException *ex);
+						 GError **error);
 void		camel_exchange_store_folder_created
 						(CamelExchangeStore *estore,
 						 const gchar *name,
